;; Generated package description from polymode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "polymode" "0.2.2" "Extensible framework for multiple major modes" '((emacs "25")) :commit "44265e35161d77f6eaa09388ea2256b89bd5dcc8" :maintainer '("Vitalie Spinu" . "spinuvit@gmail.com") :keywords '("languages" "multi-modes" "processes") :url "https://github.com/polymode/polymode")
